
Linux eduVPN client and Python API
==================================

This is the GNU/Linux desktop client for eduVPN. It also is a Python client API.

Read more about eduVPN on the eduVPN website http://eduvpn.org/.

Installation
============

The recommended way to install the eduVPN client for Linux is using one of the packages for your Linux distribution.
The online documentation at [http://python-eduvpn-client.readthedocs.io](http://python-eduvpn-client.readthedocs.io)
contains detailed installation instructions.

To directly install eduVPN from a checkout of this repository run:

```bash
$ python3 -m venv venv
$ venv/bin/pip install ".[gui]"
```
